==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/GridColumnWidthChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnDescriptionMetadata } from "./ColumnDescriptionMetadata";
import { ColumnWidthDescriptionMetadata } from "./ColumnWidthDescriptionMetadata";
import { GridColumnWidthChangedEventArgsDescription } from "./GridColumnWidthChangedEventArgsDescription";
/**
 * @hidden
 */
var GridColumnWidthChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnWidthChangedEventArgsDescriptionMetadata, _super);
    function GridColumnWidthChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnWidthChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridColumnWidthChangedEventArgsDescriptionMetadata.a == null) {
            GridColumnWidthChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnWidthChangedEventArgsDescriptionMetadata.c(GridColumnWidthChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(GridColumnWidthChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridColumnWidthChangedEventArgsDescriptionMetadata.a);
        ColumnDescriptionMetadata.d(a);
        ColumnWidthDescriptionMetadata.d(a);
    };
    GridColumnWidthChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Column", "ExportedType:Column");
        a.item("OldWidth", "ExportedType:ColumnWidth");
        a.item("NewWidth", "ExportedType:ColumnWidth");
    };
    GridColumnWidthChangedEventArgsDescriptionMetadata.d = function (a) {
        GridColumnWidthChangedEventArgsDescriptionMetadata.b(a);
        a.u("GridColumnWidthChangedEventArgs", function () { return new GridColumnWidthChangedEventArgsDescription(); });
        a.t("GridColumnWidthChangedEventArgs", GridColumnWidthChangedEventArgsDescriptionMetadata.a);
    };
    GridColumnWidthChangedEventArgsDescriptionMetadata.$t = markType(GridColumnWidthChangedEventArgsDescriptionMetadata, 'GridColumnWidthChangedEventArgsDescriptionMetadata');
    GridColumnWidthChangedEventArgsDescriptionMetadata.a = null;
    return GridColumnWidthChangedEventArgsDescriptionMetadata;
}(Base));
export { GridColumnWidthChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/GridColumnWidthChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ColumnWidthDescriptionMetadata } from "./ColumnWidthDescriptionMetadata";
import { GridColumnWidthChangedEventArgsDescription } from "./GridColumnWidthChangedEventArgsDescription";
/**
 * @hidden
 */
var GridColumnWidthChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnWidthChangedEventArgsDescriptionMetadata, _super);
    function GridColumnWidthChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnWidthChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridColumnWidthChangedEventArgsDescriptionMetadata.a == null) {
            GridColumnWidthChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnWidthChangedEventArgsDescriptionMetadata.c(GridColumnWidthChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridColumnWidthChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridColumnWidthChangedEventArgsDescriptionMetadata.a);
        DataGridColumnDescriptionMetadata.d(a);
        ColumnWidthDescriptionMetadata.d(a);
    };
    GridColumnWidthChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Column", "ExportedType:DataGridColumn");
        a.item("OldWidth", "ExportedType:ColumnWidth");
        a.item("NewWidth", "ExportedType:ColumnWidth");
    };
    GridColumnWidthChangedEventArgsDescriptionMetadata.d = function (a) {
        GridColumnWidthChangedEventArgsDescriptionMetadata.b(a);
        a.aa("GridColumnWidthChangedEventArgs", function () { return new GridColumnWidthChangedEventArgsDescription(); });
        a.z("GridColumnWidthChangedEventArgs", GridColumnWidthChangedEventArgsDescriptionMetadata.a);
    };
    GridColumnWidthChangedEventArgsDescriptionMetadata.$t = markType(GridColumnWidthChangedEventArgsDescriptionMetadata, 'GridColumnWidthChangedEventArgsDescriptionMetadata');
    GridColumnWidthChangedEventArgsDescriptionMetadata.a = null;
    return GridColumnWidthChangedEventArgsDescriptionMetadata;
}(Base));
export { GridColumnWidthChangedEventArgsDescriptionMetadata };
